@@ -15,7 +15,7 @@ __author__ = "Ali Onur Uyar"
 __copyright__ = "Copyright 2011, Ali Onur Uyar"
 __credits__ = ["Samuel Stauffer"]
 __license__ = "GPL"
-__version__ = "0.9.1"
+__version__ = "0.9.2"
 __maintainer__ = "Ali Onur Uyar"
 __email__ = "aouyar at gmail.com"
 __status__ = "Development"
@@ -114,7 +114,8 @@ class MuninPlugin:
         self._dirtyConfig = False
         if (self.plugin_name is not None and argv is not None and len(argv) > 0 
             and re.search('_$', self.plugin_name)):
-            mobj = re.match("%s(\S+)$" % self.plugin_name, argv[0])
+            mobj = re.match("%s(\S+)$" % self.plugin_name, 
+                            os.path.basename(argv[0]))
             if mobj:
                 self.arg0 = mobj.group(1)
         self._parseEnv()
